@@ -5,7 +5,7 @@
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfu.cpp,v 1.36 2003/06/15 09:11:46 cade Exp $
+ * $Id: vfu.cpp,v 1.45 2005/06/01 23:13:08 cade Exp $
  *
  */
 
@@ -89,6 +89,7 @@
   VString shell_browser;
   VString shell_editor;
   VString shell_options;
+  VString shell_diff;
   VString shell_prog;
   
   VString user_id_str;
@@ -101,7 +102,6 @@
   VString filename_tree;
   VString filename_size_cache;
   VString filename_ffr; /* file find results */
-  VString filename_atl;
 
   char TF::_full_name[MAX_PATH]; 
   
@@ -342,14 +342,9 @@ void TF::refresh_view()
       {
       VString str;
       if ( _is_dir && _size == -1 )
-        {
         str = "[DIR]";
-        }
       else
-        {
-        str.fi( _size );
-        str_comma( str );
-        }
+        str = fsize_fmt( _size );
       sprintf( stsize, "%14s", (const char*)(str) );
       strcat( stsize, " " ); /* field separator */
       }
@@ -415,7 +410,7 @@ void TF::update_stat( const struct stat* a_new_stat = NULL,
   if ( _is_dir )
     _size = -1; /* FIXME: some auto thing here? */
   else
-    _size = _st.st_size;
+    _size = (unsigned)_st.st_size;
   _color = get_item_color( this );
   
   drop_view();
@@ -580,6 +575,13 @@ void vfu_init()
   #ifdef _TARGET_GO32_
   str_tr( home_path, "\\", "/" );
   #endif
+
+
+  #ifdef _TARGET_GO32_
+  shell_diff = "fc";
+  #else
+  shell_diff = "/usr/bin/diff";
+  #endif
   
   /* 
      FIXME: this should something relevant to the home_path 
@@ -741,29 +743,16 @@ int vfu_exit( const char* a_path )
 
 void vfu_run()
 {
-  char t[128];
   say1center( HEADER );
   say2center( CONTACT );
 
-  int ox = con_max_x();
-  int oy = con_max_y();
-
   /* int oldFLI = -1; // quick view */
   int ch = 0;
   while (4)
     {
-    if ( ox != con_max_x() || oy != con_max_y() )
-      {
-      ox = con_max_x();
-      oy = con_max_y();
-      do_draw = 3;
-      }
     if (do_draw) 
       {
-      if ( do_draw > 2 )
-	    {
-        vfu_reset_screen();
-	    }
+      if ( do_draw > 2 ) vfu_reset_screen();
       if ( do_draw > 1 ) do_draw_status = 1;
       vfu_redraw(); 
       do_draw = 0; 
@@ -785,6 +774,7 @@ void vfu_run()
     show_pos( FLI+1, files_count ); /* FIXME: should this be in vfu_redraw()? */  
     
     ch = con_getch();
+    if( ch == 0 ) ch = KEY_CTRL_L;
     if ( ch >= 'A' && ch <= 'Z' ) ch = tolower( ch );
     say1( "" ); 
     if ( user_id_str == "root" )
@@ -802,9 +792,11 @@ void vfu_run()
       case '6'       :
       case '7'       :
       case '8'       :
-      case '0'       :
-      case '.'       : vfu_toggle_view_fields( ch ); break;
-
+      case '0'       : vfu_toggle_view_fields( ch ); break;
+      
+      case '.'       : vfu_toggle_view_fields( ch ); 
+                       vfu_rescan_files( 0 ); break;
+      
       case 's'       : vfu_inc_search(); break;
 
       case KEY_CTRL_L: do_draw = 3; break;
@@ -1056,10 +1048,6 @@ void vfu_done()
   if ( dir_tree.count() && dir_tree_changed ) tree_save();
 
   vfu_settings_save();
-
-  if ( access( filename_atl, F_OK ) == 0 )
-    unlink( filename_atl );
-  
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1365,8 +1353,7 @@ void vfu_action_plus( int key )
       { /* file */
       int z;
       for ( z = 0; z < archive_extensions.count(); z++ )
-        if ( FNMATCH_OC( archive_extensions[z], fi->name_ext(),
-	                 opt.lower_case_ext_config ) == 0 )
+        if ( FNMATCH_OC( archive_extensions[z], fi->name_ext(), opt.lower_case_ext_config ) == 0 )
           {
           z = -1; /* FIXME: this shouldn't be -1 for TRUE really :) */
           break;
@@ -1376,10 +1363,8 @@ void vfu_action_plus( int key )
         work_mode = WM_ARCHIVE;
         archive_name = fi->name();
         archive_path = ""; /* NOTE: archives' root dir is `' but not `/'! */
-        filename_atl = vfu_temp(); /* this is help for rx_*'s */
-        setenv( RX_TEMP_LIST, filename_atl, 1 );
         vfu_read_files();
-        say1( "ARCHIVE mode activated. ( some keys/commands are disabled! )" );
+        say1( "ARCHIVE mode activated ( some keys/commands are disabled! )" );
         } else
       if ( key == KEY_ENTER && vfu_user_external_find( KEY_ENTER, fi->ext(), fi->type_str(), NULL ) != -1 )
         vfu_user_external_exec( KEY_ENTER );
@@ -1444,11 +1429,6 @@ void vfu_action_minus()
       work_mode = WM_NORMAL;
       archive_name = "";
       archive_path = ""; /* NOTE: this shouldn't be `/'! */
-      #ifndef _TARGET_GO32_
-      unsetenv( RX_TEMP_LIST );
-      #endif
-      if ( access( filename_atl, F_OK ) == 0 )
-        unlink( filename_atl );
       vfu_chdir( "." );
       }
     }
@@ -1636,6 +1616,8 @@ void vfu_global_select()
       return; 
       };
     mb.undef();
+    mb.push( "A Select to begin" );
+    mb.push( "E Select to end" );
     mb.push( "--searching--" );
     mb.push( "F Find string (no case)" );
     mb.push( "S Scan string (case sense)" );
@@ -1646,8 +1628,10 @@ void vfu_global_select()
 //    mb.push( "M Mode/Attributes" );
     if ( vfu_menu_box( 50, 5, "Extended G.Select" ) == -1 ) return;
     ch = menu_box_info.ec;
-    if (ch == 'S') ch = 'B'; /* 'B' trans */
-    if (ch == 'H') ch = 'E'; /* 'E' trans */
+    if (ch == 'S') ch = 'B'; /* 'B' trans scan */
+    if (ch == 'H') ch = 'E'; /* 'E' trans hex  */
+    if (ch == 'A') ch = '<'; /* '<' trans to begin  */
+    if (ch == 'E') ch = '>'; /* '>' trans to end    */
     }
 
   switch(ch)
@@ -1881,6 +1865,18 @@ void vfu_global_select()
                 do_draw = 1;
                 }
               }; break;
+    case '<' : {
+               if( files_count > 0)
+                 for (int z = 0; z <= FLI; z++)
+                   if (!files_list[z]->is_dir())
+                     files_list[z]->sel = 1;
+               }; break;
+    case '>' : {
+               if( files_count > 0)
+                 for (int z = FLI; z < files_count; z++)
+                   if (!files_list[z]->is_dir())
+                     files_list[z]->sel = 1;
+               }; break;
     }
   update_status();
   do_draw = 1;
@@ -2027,6 +2023,7 @@ void bookmark_goto( int n )
     if ( n == -1 ) return;
     n++;
     }
+  // FIXME: neshto ne raboti :/  
   switch( menu_box_info.ec )
     {
     case '`' : vfu_chdir( NULL ); return;
@@ -2825,6 +2822,7 @@ void vfu_inc_search()
   VString str;
   say1( "Enter search pattern: ( use TAB to advance )" );
   int key = con_getch();
+  VRegexp size_re("^size:(\\d+)$");
   while( ( key >= 32 && key <= 255 ) || key == 8 || key == KEY_BACKSPACE || key == 9 )
     {
     if ( key == 8 || key == KEY_BACKSPACE )
@@ -2849,12 +2847,19 @@ void vfu_inc_search()
     int found = 0;
     int loops = 0;
     VString s_mask = str;
-    vfu_expand_mask( s_mask );
+    int s_size = 0;
+    if( size_re.m( str ) )
+      s_size = atoi( size_re[1] );
+    else
+      vfu_expand_mask( s_mask );
     while(1)
       {
       if ( z > file_list_index.max() ) z = file_list_index.min();
       if ( z < file_list_index.min() ) z = file_list_index.max();
-      found = ( FNMATCH( s_mask, files_list[z]->name_ext() ) == 0 );
+      if( s_size )
+        found = files_list[z]->size() == s_size;
+      else
+        found = ( FNMATCH( s_mask, files_list[z]->name_ext() ) == 0 );
       if ( found ) break;
       z += direction;
       if ( loops++ > files_count ) break;
