@@ -5,7 +5,7 @@
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfu.h,v 1.11 2003/04/28 17:17:01 cade Exp $
+ * $Id: vfu.h,v 1.13 2005/02/11 01:02:04 cade Exp $
  *
  */
 
@@ -238,6 +238,7 @@
 
   extern VString shell_browser;
   extern VString shell_editor;
+  extern VString shell_diff;
   extern VString shell_prog;
 
   extern VString user_id_str;
@@ -250,8 +251,6 @@
   extern VString filename_tree;
   extern VString filename_size_cache;
   extern VString filename_ffr; /* file find results */
-  extern VString filename_atl; /* bad name I know, it stands for
-                                 `archive temp list' */
 
 /*######################################################################*/
 
