@@ -5,7 +5,7 @@
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfudir.cpp,v 1.23 2003/06/15 08:53:58 cade Exp $
+ * $Id: vfudir.cpp,v 1.26 2005/06/01 23:13:08 cade Exp $
  *
  */
 
@@ -593,7 +593,7 @@ fsize_t __tree_rebuild_process( const char* path )
       }
     else
       { /* file */
-      size += st.st_size;
+      size += (unsigned)st.st_size;
       }  
     
     }
@@ -960,13 +960,26 @@ fsize_t size_cache_get( const char *s )
     return -1;  
 }
 
-void size_cache_set( const char *s, fsize_t size )
+void size_cache_set( const char *s, fsize_t size, int sort )
 {
   int z = size_cache_index( s );
   if ( z != -1 )
-    size_cache.del( z );
+    {
+    size_cache.set( z, size_cache_compose_key( s, size ) );
+    }
+  else
+    {
+    size_cache.push( size_cache_compose_key( s, size ) );
+    if( sort )
+      size_cache.sort( 0, size_cache_cmp );
+    }
+}
+
+// this function is used to add quickly entries to the cache
+// it REQUIRES that size_cache_sort() is called after it!
+void size_cache_append( const char *s, fsize_t size )
+{
   size_cache.push( size_cache_compose_key( s, size ) );
-  size_cache.sort( 0, size_cache_cmp );
 }
 
 void size_cache_clean( const char *s )
@@ -1120,11 +1133,11 @@ fsize_t __dir_size_process( const char* path )
       else
         {
         size += dir_size;
-        size_cache_set( new_name, dir_size );
+        size_cache_append( new_name, dir_size );
         }
       }
     else
-      size += st.st_size;  
+      size += (unsigned)st.st_size;  
     
     }
   closedir(dir);
@@ -1140,6 +1153,7 @@ fsize_t vfu_dir_size( const char *s )
   expand_path( s, t );
   size_cache_clean( t );
   str_fix_path( t );
+  size_cache_clean( t );
   fsize_t size = __dir_size_process( t );
   size_cache_set( t, size );
   return size;
